<?php

/**
 * @file
 *   Contains features hooks for adtoma fusion module
 */

###########################
## SPACE COMPONENT HOOKS ##
###########################

/**
 * Implement hook_features_export
 */
function adtoma_fusion_space_features_export($data, &$export, $module_name) {
  foreach ($data as $item) {
    if (!isset($export['features']['adtoma_fusion_space'])) {
      $export['features']['adtoma_fusion_space'] = array();
      $export['dependencies']['token'] = 'token';
      $export['dependencies']['adtoma_fusion'] = 'adtoma_fusion';
    }
    $export['features']['adtoma_fusion_space'][$item] = $item;
  }
}

/**
 * Implement hook_features_export_options
 */
function adtoma_fusion_space_features_export_options() {
  $options = array();
  $spaces = adtoma_fusion_space_load_multiple();
  foreach ($spaces as $space) {
    $options[$space->name] = $space->description ? "$space->description ($space->name)" : $space->name;
  }
  return $options;
}

/**
 * Implement hook_features_export_render
 */
function adtoma_fusion_space_features_export_render($module_name, $data, $export = NULL) {
  $code = array();
  $code[] = '  $spaces = array();' . "\n";
  foreach ($data as $name) {
    $space = adtoma_fusion_space_load_from_name($name);
    $code[] = "  /**\n   * Export data for space: " . $space->name . "\n   */";
    $code[] = '  $spaces["'. $name .'"] = ' . features_var_export($space) . ';';
  }
  $code[] = "\n" . 'return $spaces;';

  $rendered_code = implode("\n", $code);
  return array('adtoma_fusion_default_spaces' => $rendered_code);
}

/**
 * Implement hook_features_export_revert
function adtoma_fusion_space_features_export_revert($module_name) {
  dpm(__FUNCTION__);
  $defaults = module_invoke($module_name, 'adtoma_fusion_default_spaces');
  if (!empty($defaults)) {
    foreach ($defaults as $name => $space) {
      unset($space->id);
      adtoma_fusion_space_save($space);
    }
  }
}
 */

/**
 * Implement hook_features_export_rebuild
function adtoma_fusion_space_features_export_rebuild($module_name) {
  dpm(__FUNCTION__);
  $defaults = module_invoke($module_name, 'adtoma_fusion_default_spaces');
  if (!empty($defaults)) {
    foreach ($defaults as $name => $space) {
      adtoma_fusion_space_save($space->name);
    }
  }
}
*/


/**
 * @file
 *   Contains features hooks for adtoma fusion module
 */

###########################
## CONFIG COMPONENT HOOKS ##
###########################

/**
 * Implement hook_features_export
 */
function adtoma_fusion_configuration_features_export($data, &$export, $module_name) {
  foreach ($data as $item) {
    if (!isset($export['features']['adtoma_fusion_configuration'])) {
      $export['features']['adtoma_fusion_configuration'] = array();
      $export['dependencies']['token'] = 'token';
      $export['dependencies']['adtoma_fusion'] = 'adtoma_fusion';
    }
    $export['features']['adtoma_fusion_configuration'][$item] = $item;
  }
}

/**
 * Implement hook_features_export_options
 */
function adtoma_fusion_configuration_features_export_options() {
  $options = array();
  $configurations = adtoma_fusion_config_load_multiple();
  foreach ($configurations as $configuration) {
    $options[$configuration->machine_name] = $configuration->description ? "$configuration->description ($configuration->machine_name)" : $configuration->machine_name;
  }
  return $options;
}

/**
 * Implement hook_features_export_render
 */
function adtoma_fusion_configuration_features_export_render($module_name, $data, $export = NULL) {
  $code = array();
  $code[] = '  $configuration = array();' . "\n";
  foreach ($data as $name) {
    $configuration = adtoma_fusion_config_load($name);
    $code[] = "  /**\n   * Export data for configuration: " . $configuration->name . "\n   */";
    $code[] = '  $configuration["'. $name .'"] = ' . features_var_export($configuration) . ';';
  }
  $code[] = "\n" . 'return $configuration;';

  $rendered_code = implode("\n", $code);
  return array('adtoma_fusion_default_configuration' => $rendered_code);
}

